@@ -1,7 +1,11 @@
 from contextlib import contextmanager
 from functools import wraps
-from testfixtures import Comparison, diff, compare
-from testfixtures.utils import match_type_or_instance
+from typing import Union, Type, Callable
+
+from testfixtures import diff, compare
+
+ExceptionOrType = Union[Exception, Type[Exception]]
+
 
 param_docs = """
 
@@ -35,26 +39,34 @@ class ShouldRaise(object):
     #: Can be used to inspect specific attributes of the exception.
     raised = None
 
-    def __init__(self, exception=None, unless=False):
+    def __init__(self, exception: ExceptionOrType = None, unless: bool = False):
         self.exception = exception
         self.expected = not unless
 
     def __enter__(self):
         return self
 
-    def __exit__(self, type, actual, traceback):
+    def __exit__(self, type_, actual, traceback):
         __tracebackhide__ = True
         self.raised = actual
         if self.expected:
             if self.exception:
+                if actual is not None:
+                    if isinstance(self.exception, type):
+                        actual = type(actual)
+                        if self.exception is not actual:
+                            return False
+                    else:
+                        if type(self.exception) is not type(actual):
+                            return False
                 compare(self.exception,
-                        match_type_or_instance(self.exception, actual),
+                        actual,
                         x_label='expected',
                         y_label='raised')
             elif not actual:
                 raise AssertionError('No exception raised!')
         elif actual:
-            raise AssertionError('%r raised, no exception expected' % actual)
+            return False
         return True
 
 
@@ -66,11 +78,11 @@ class should_raise:
     raised.
     """ + param_docs
 
-    def __init__(self, exception=None, unless=None):
+    def __init__(self, exception: ExceptionOrType = None, unless: bool = None):
         self.exception = exception
         self.unless = unless
 
-    def __call__(self, target):
+    def __call__(self, target: Callable) -> Callable:
 
         @wraps(target)
         def _should_raise_wrapper(*args, **kw):
@@ -81,7 +93,7 @@ class should_raise:
 
 
 @contextmanager
-def ShouldAssert(expected_text):
+def ShouldAssert(expected_text: str):
     """
     A context manager to check that an :class:`AssertionError`
     is raised and its text is as expected.
